@@ -3,9 +3,11 @@ pub mod book;
 pub mod math;
 pub mod code;
 pub mod theatre;
+pub mod novel;
 
 use basic::*;
 use book::*;
 use math::*;
 use code::*;
 use theatre::*;
+use novel::*;
